==> webkit2gtk_2.34.6.2.orig.tar.xz: webkit2gtk-2.34.6.2/Source/WebCore/page/ResizeObservation.h <==
/*
 * Copyright (C) 2019 Igalia S.L.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(RESIZE_OBSERVER)
#include "FloatRect.h"
#include "LayoutSize.h"

#include <wtf/RefCounted.h>
#include <wtf/WeakPtr.h>

namespace WebCore {

class Element;

class ResizeObservation : public RefCounted<ResizeObservation> {
    WTF_MAKE_FAST_ALLOCATED;
public:
    static Ref<ResizeObservation> create(Element& target);

    ~ResizeObservation();

    void updateObservationSize(const LayoutSize&);
    LayoutSize computeObservedSize() const;
    LayoutPoint computeTargetLocation() const;
    FloatRect computeContentRect() const;

    bool elementSizeChanged(LayoutSize&) const;
    Element* target() const { return m_target.get(); }
    size_t targetElementDepth() const;

private:
    ResizeObservation(Element& target);

    WeakPtr<Element> m_target;
    LayoutSize m_lastObservationSize;
};

} // namespace WebCore

#endif // ENABLE(RESIZE_OBSERVER)

==> webkit2gtk_2.36.3.1.orig.tar.xz: webkit2gtk-2.36.3.1/Source/WebCore/page/ResizeObservation.h <==
/*
 * Copyright (C) 2019 Igalia S.L.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "FloatRect.h"
#include "LayoutSize.h"
#include "ResizeObserverBoxOptions.h"

#include <wtf/RefCounted.h>
#include <wtf/WeakPtr.h>

namespace WebCore {

class Element;

class ResizeObservation : public RefCounted<ResizeObservation> {
    WTF_MAKE_FAST_ALLOCATED;
public:
    static Ref<ResizeObservation> create(Element& target, ResizeObserverBoxOptions);

    ~ResizeObservation();
    
    struct BoxSizes {
        LayoutSize contentBoxSize;
        LayoutSize contentBoxLogicalSize;
        LayoutSize borderBoxLogicalSize;
    };

    std::optional<BoxSizes> elementSizeChanged() const;
    void updateObservationSize(const BoxSizes&);

    FloatRect computeContentRect() const;
    FloatSize borderBoxSize() const;
    FloatSize contentBoxSize() const;
    FloatSize snappedContentBoxSize() const;

    Element* target() const { return m_target.get(); }
    ResizeObserverBoxOptions observedBox() const { return m_observedBox; }
    size_t targetElementDepth() const;

private:
    ResizeObservation(Element&, ResizeObserverBoxOptions);

    BoxSizes computeObservedSizes() const;
    LayoutPoint computeTargetLocation() const;

    WeakPtr<Element> m_target;
    BoxSizes m_lastObservationSizes;
    ResizeObserverBoxOptions m_observedBox;
};

} // namespace WebCore
